set quoted_identifier on;

--
-- In MS SQL  we can't use TEXT type like in PgSQL or MySQL:
--
-- The text, ntext, and image data types cannot be compared or sorted, 
-- except when using IS NULL or LIKE operator.
--
-- We use VARCHAR() instead.
--

CREATE TABLE "dict" (
	"url_id" "int" NOT NULL ,
	"word"    varchar (32) NOT NULL ,
	"intag" "int" NOT NULL 
);
CREATE  INDEX "dict_url_id" ON "dict" ("url_id");
CREATE  INDEX "dict_word_url_id" ON "dict" ("word", "url_id");

CREATE TABLE bdict (
  word  VARCHAR(255) NOT NULL,
  secno INT NOT NULL,
  intag IMAGE NOT NULL
);
CREATE INDEX bdict_word ON bdict (word);


CREATE TABLE "url" (
        "rec_id"          "int" IDENTITY(1,1) NOT NULL PRIMARY KEY,
        "status"          "int" NOT NULL DEFAULT 0,
        "docsize"         "int" NOT NULL DEFAULT 0,
        "next_index_time" "int" NOT NULL,
        "last_mod_time"   "int" NOT NULL DEFAULT 0,
        "referrer"        "int" NOT NULL DEFAULT 0,
        "hops"            "int" NOT NULL DEFAULT 0,
        "crc32"           "int" NOT NULL DEFAULT -1,
        "seed"            "int" NOT NULL DEFAULT 0,
        "bad_since_time"  "int"     NULL,
        "site_id"         "int"     NULL,
        "server_id"       "int"     NULL,
        "shows"           "int" NOT NULL DEFAULT 0,
        "pop_rank"        float NOT NULL DEFAULT 0,
        "url"             varchar(4096)  NOT NULL,
        CONSTRAINT "UQ_url_url" UNIQUE ("url")
);


CREATE UNIQUE INDEX "url_url" ON "url" ( "url" );
CREATE INDEX "url_crc" ON "url" ( "crc32" );
CREATE INDEX "url_seed" ON "url" ( "seed" );
CREATE INDEX "url_referrer" ON "url" ( "referrer" );
CREATE INDEX "url_next_index_time" ON "url" ( "next_index_time" );
CREATE INDEX "url_status" ON "url" ( "status" );
CREATE INDEX "url_bad_since_time" ON "url" ( "bad_since_time" );
CREATE INDEX "url_hops" ON "url" ( "hops" );
CREATE INDEX "url_siteid" ON "url" ( "site_id" ); 


CREATE TABLE "urlinfo" (
       "url_id" "int"         NOT NULL,
       "sname"  VARCHAR(96)   NOT NULL,
       "sval"   TEXT          NOT NULL
);
CREATE INDEX "urlinfo_id" ON "urlinfo" (url_id);


CREATE TABLE "server" (
        "rec_id"     int           not null primary key,
        "enabled"    int           not null default 0,
        "url"        varchar(4096) not null default '',
        "tag"        varchar(96)   not null default '',
        "category"   int           not null default 0,
        "command"    char(1)       not null default 'S',
        "ordre"      int           not null default 0,
        "parent"     int           not null default 0,
        "weight"     float         not null default 1,
        "pop_weight" float         not null default 0
);
CREATE INDEX "srv_ordre"   ON "server" ("ordre");
CREATE INDEX "srv_parent"  ON "server" ("parent");
CREATE INDEX "srv_command" ON "server" ("command");

CREATE TABLE "srvinfo" (
       srv_id int           NOT NULL,
       sname  varchar(96)   NOT NULL,
       sval   varchar(4096) NOT NULL
);
CREATE INDEX srvinfo_id ON srvinfo (srv_id);


CREATE TABLE "links" (
        "ot"     int   not null,
        "k"      int   not null,
        "weight" float not null default 0
);
CREATE UNIQUE INDEX links_links ON links (ot, k);
CREATE INDEX links_ot ON links (ot);
CREATE INDEX links_k ON links (k);


CREATE TABLE "categories" (
        "rec_id" "int" IDENTITY(1,1) NOT NULL PRIMARY KEY,
        "path" varchar(10) DEFAULT '' NOT NULL,
        "link" varchar(10) DEFAULT '' NOT NULL,
        "name" varchar(64) DEFAULT '' NOT NULL
);

CREATE TABLE "qtrack" (
        "rec_id" "int" IDENTITY(1,1) NOT NULL PRIMARY KEY,
        "ip"     varchar(16)         NOT NULL,
        "qwords" varchar(4096)       NOT NULL,
        "qtime"  int                 NOT NULL,
        "found"  int                 NOT NULL
);
CREATE INDEX qtrack_ipt ON qtrack(ip,qtime);


CREATE TABLE "qinfo" (
       "q_id"  int,
       "name"  text,
       "value" text
);
CREATE INDEX qinfo_id ON qinfo (q_id);


CREATE TABLE crossdict (
  url_id int DEFAULT '0' NOT NULL,
  ref_id int DEFAULT '0' NOT NULL,
  intag  int DEFAULT '0' NOT NULL,
  word   varchar(32) DEFAULT '0' NOT NULL
);

CREATE INDEX crossdict_url_id ON crossdict (url_id);
CREATE INDEX crossdict_ref_id ON crossdict (ref_id);
CREATE INDEX crossdict_word ON crossdict (word);
CREATE INDEX crossdict_word_url_id ON crossdict (word, url_id);


CREATE TABLE wrdstat (
  word varchar(64) NOT NULL,
  snd varchar(16) NOT NULL,
  cnt int NOT NULL
);
CREATE INDEX wrdstat_word ON wrdstat (word);
CREATE INDEX wrdstat_snd  ON wrdstat (snd);
CREATE TABLE dict00 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict00   ON dict00 (url_id);

CREATE TABLE dict01 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict01   ON dict01 (url_id);

CREATE TABLE dict02 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict02   ON dict02 (url_id);

CREATE TABLE dict03 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict03   ON dict03 (url_id);

CREATE TABLE dict04 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict04   ON dict04 (url_id);

CREATE TABLE dict05 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict05   ON dict05 (url_id);

CREATE TABLE dict06 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict06   ON dict06 (url_id);

CREATE TABLE dict07 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict07   ON dict07 (url_id);

CREATE TABLE dict08 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict08   ON dict08 (url_id);

CREATE TABLE dict09 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict09   ON dict09 (url_id);

CREATE TABLE dict0A (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict0A   ON dict0A (url_id);

CREATE TABLE dict0B (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict0B   ON dict0B (url_id);

CREATE TABLE dict0C (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict0C   ON dict0C (url_id);

CREATE TABLE dict0D (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict0D   ON dict0D (url_id);

CREATE TABLE dict0E (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict0E   ON dict0E (url_id);

CREATE TABLE dict0F (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict0F   ON dict0F (url_id);


CREATE TABLE dict10 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict10   ON dict10 (url_id);

CREATE TABLE dict11 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict11   ON dict11 (url_id);

CREATE TABLE dict12 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict12   ON dict12 (url_id);

CREATE TABLE dict13 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict13   ON dict13 (url_id);

CREATE TABLE dict14 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict14   ON dict14 (url_id);

CREATE TABLE dict15 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict15   ON dict15 (url_id);

CREATE TABLE dict16 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict16   ON dict16 (url_id);

CREATE TABLE dict17 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict17   ON dict17 (url_id);

CREATE TABLE dict18 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict18   ON dict18 (url_id);

CREATE TABLE dict19 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict19   ON dict19 (url_id);

CREATE TABLE dict1A (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict1A   ON dict1A (url_id);

CREATE TABLE dict1B (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict1B   ON dict1B (url_id);

CREATE TABLE dict1C (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict1C   ON dict1C (url_id);

CREATE TABLE dict1D (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict1D   ON dict1D (url_id);

CREATE TABLE dict1E (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict1E   ON dict1E (url_id);

CREATE TABLE dict1F (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict1F   ON dict1F (url_id);

CREATE TABLE dict20 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict20   ON dict20 (url_id);

CREATE TABLE dict21 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict21   ON dict21 (url_id);

CREATE TABLE dict22 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict22   ON dict22 (url_id);

CREATE TABLE dict23 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict23   ON dict23 (url_id);

CREATE TABLE dict24 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict24   ON dict24 (url_id);

CREATE TABLE dict25 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict25   ON dict25 (url_id);

CREATE TABLE dict26 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict26   ON dict26 (url_id);

CREATE TABLE dict27 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict27   ON dict27 (url_id);

CREATE TABLE dict28 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict28   ON dict28 (url_id);

CREATE TABLE dict29 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict29   ON dict29 (url_id);

CREATE TABLE dict2A (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict2A   ON dict2A (url_id);

CREATE TABLE dict2B (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict2B   ON dict2B (url_id);

CREATE TABLE dict2C (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict2C   ON dict2C (url_id);

CREATE TABLE dict2D (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict2D   ON dict2D (url_id);

CREATE TABLE dict2E (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict2E   ON dict2E (url_id);

CREATE TABLE dict2F (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict2F   ON dict2F (url_id);

CREATE TABLE dict30 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict30   ON dict30 (url_id);

CREATE TABLE dict31 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict31   ON dict31 (url_id);

CREATE TABLE dict32 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict32   ON dict32 (url_id);

CREATE TABLE dict33 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict33   ON dict33 (url_id);

CREATE TABLE dict34 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict34   ON dict34 (url_id);

CREATE TABLE dict35 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict35   ON dict35 (url_id);

CREATE TABLE dict36 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict36   ON dict36 (url_id);

CREATE TABLE dict37 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict37   ON dict37 (url_id);

CREATE TABLE dict38 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict38   ON dict38 (url_id);

CREATE TABLE dict39 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict39   ON dict39 (url_id);

CREATE TABLE dict3A (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict3A   ON dict3A (url_id);

CREATE TABLE dict3B (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict3B   ON dict3B (url_id);

CREATE TABLE dict3C (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict3C   ON dict3C (url_id);

CREATE TABLE dict3D (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict3D   ON dict3D (url_id);

CREATE TABLE dict3E (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict3E   ON dict3E (url_id);

CREATE TABLE dict3F (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict3F   ON dict3F (url_id);

CREATE TABLE dict40 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict40   ON dict40 (url_id);

CREATE TABLE dict41 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict41   ON dict41 (url_id);

CREATE TABLE dict42 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict42   ON dict42 (url_id);

CREATE TABLE dict43 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict43   ON dict43 (url_id);

CREATE TABLE dict44 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict44   ON dict44 (url_id);

CREATE TABLE dict45 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict45   ON dict45 (url_id);

CREATE TABLE dict46 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict46   ON dict46 (url_id);

CREATE TABLE dict47 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict47   ON dict47 (url_id);

CREATE TABLE dict48 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict48   ON dict48 (url_id);

CREATE TABLE dict49 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict49   ON dict49 (url_id);

CREATE TABLE dict4A (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict4A   ON dict4A (url_id);

CREATE TABLE dict4B (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict4B   ON dict4B (url_id);

CREATE TABLE dict4C (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict4C   ON dict4C (url_id);

CREATE TABLE dict4D (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict4D   ON dict4D (url_id);

CREATE TABLE dict4E (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict4E   ON dict4E (url_id);

CREATE TABLE dict4F (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict4F   ON dict4F (url_id);

CREATE TABLE dict50 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict50   ON dict50 (url_id);

CREATE TABLE dict51 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict51   ON dict51 (url_id);

CREATE TABLE dict52 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict52   ON dict52 (url_id);

CREATE TABLE dict53 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict53   ON dict53 (url_id);

CREATE TABLE dict54 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict54   ON dict54 (url_id);

CREATE TABLE dict55 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict55   ON dict55 (url_id);

CREATE TABLE dict56 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict56   ON dict56 (url_id);

CREATE TABLE dict57 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict57   ON dict57 (url_id);

CREATE TABLE dict58 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict58   ON dict58 (url_id);

CREATE TABLE dict59 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict59   ON dict59 (url_id);

CREATE TABLE dict5A (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict5A   ON dict5A (url_id);

CREATE TABLE dict5B (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict5B   ON dict5B (url_id);

CREATE TABLE dict5C (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict5C   ON dict5C (url_id);

CREATE TABLE dict5D (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict5D   ON dict5D (url_id);

CREATE TABLE dict5E (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict5E   ON dict5E (url_id);

CREATE TABLE dict5F (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict5F   ON dict5F (url_id);

CREATE TABLE dict60 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict60   ON dict60 (url_id);

CREATE TABLE dict61 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict61   ON dict61 (url_id);

CREATE TABLE dict62 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict62   ON dict62 (url_id);

CREATE TABLE dict63 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict63   ON dict63 (url_id);

CREATE TABLE dict64 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict64   ON dict64 (url_id);

CREATE TABLE dict65 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict65   ON dict65 (url_id);

CREATE TABLE dict66 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict66   ON dict66 (url_id);

CREATE TABLE dict67 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict67   ON dict67 (url_id);

CREATE TABLE dict68 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict68   ON dict68 (url_id);

CREATE TABLE dict69 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict69   ON dict69 (url_id);

CREATE TABLE dict6A (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict6A   ON dict6A (url_id);

CREATE TABLE dict6B (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict6B   ON dict6B (url_id);

CREATE TABLE dict6C (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict6C   ON dict6C (url_id);

CREATE TABLE dict6D (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict6D   ON dict6D (url_id);

CREATE TABLE dict6E (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict6E   ON dict6E (url_id);

CREATE TABLE dict6F (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict6F   ON dict6F (url_id);

CREATE TABLE dict70 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict70   ON dict70 (url_id);

CREATE TABLE dict71 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict71   ON dict71 (url_id);

CREATE TABLE dict72 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict72   ON dict72 (url_id);

CREATE TABLE dict73 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict73   ON dict73 (url_id);

CREATE TABLE dict74 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict74   ON dict74 (url_id);

CREATE TABLE dict75 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict75   ON dict75 (url_id);

CREATE TABLE dict76 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict76   ON dict76 (url_id);

CREATE TABLE dict77 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict77   ON dict77 (url_id);

CREATE TABLE dict78 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict78   ON dict78 (url_id);

CREATE TABLE dict79 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict79   ON dict79 (url_id);

CREATE TABLE dict7A (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict7A   ON dict7A (url_id);

CREATE TABLE dict7B (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict7B   ON dict7B (url_id);

CREATE TABLE dict7C (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict7C   ON dict7C (url_id);

CREATE TABLE dict7D (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict7D   ON dict7D (url_id);

CREATE TABLE dict7E (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict7E   ON dict7E (url_id);

CREATE TABLE dict7F (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict7F   ON dict7F (url_id);

CREATE TABLE dict80 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict80   ON dict80 (url_id);

CREATE TABLE dict81 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict81   ON dict81 (url_id);

CREATE TABLE dict82 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict82   ON dict82 (url_id);

CREATE TABLE dict83 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict83   ON dict83 (url_id);

CREATE TABLE dict84 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict84   ON dict84 (url_id);

CREATE TABLE dict85 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict85   ON dict85 (url_id);

CREATE TABLE dict86 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict86   ON dict86 (url_id);

CREATE TABLE dict87 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict87   ON dict87 (url_id);

CREATE TABLE dict88 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict88   ON dict88 (url_id);

CREATE TABLE dict89 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict89   ON dict89 (url_id);

CREATE TABLE dict8A (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict8A   ON dict8A (url_id);

CREATE TABLE dict8B (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict8B   ON dict8B (url_id);

CREATE TABLE dict8C (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict8C   ON dict8C (url_id);

CREATE TABLE dict8D (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict8D   ON dict8D (url_id);

CREATE TABLE dict8E (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict8E   ON dict8E (url_id);

CREATE TABLE dict8F (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict8F   ON dict8F (url_id);

CREATE TABLE dict90 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict90   ON dict90 (url_id);

CREATE TABLE dict91 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict91   ON dict91 (url_id);

CREATE TABLE dict92 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict92   ON dict92 (url_id);

CREATE TABLE dict93 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict93   ON dict93 (url_id);

CREATE TABLE dict94 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict94   ON dict94 (url_id);

CREATE TABLE dict95 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict95   ON dict95 (url_id);

CREATE TABLE dict96 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict96   ON dict96 (url_id);

CREATE TABLE dict97 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict97   ON dict97 (url_id);

CREATE TABLE dict98 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict98   ON dict98 (url_id);

CREATE TABLE dict99 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict99   ON dict99 (url_id);

CREATE TABLE dict9A (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict9A   ON dict9A (url_id);

CREATE TABLE dict9B (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict9B   ON dict9B (url_id);

CREATE TABLE dict9C (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict9C   ON dict9C (url_id);

CREATE TABLE dict9D (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict9D   ON dict9D (url_id);

CREATE TABLE dict9E (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict9E   ON dict9E (url_id);

CREATE TABLE dict9F (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdict9F   ON dict9F (url_id);

CREATE TABLE dictA0 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictA0   ON dictA0 (url_id);

CREATE TABLE dictA1 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictA1   ON dictA1 (url_id);

CREATE TABLE dictA2 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictA2   ON dictA2 (url_id);

CREATE TABLE dictA3 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictA3   ON dictA3 (url_id);

CREATE TABLE dictA4 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictA4   ON dictA4 (url_id);

CREATE TABLE dictA5 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictA5   ON dictA5 (url_id);

CREATE TABLE dictA6 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictA6   ON dictA6 (url_id);

CREATE TABLE dictA7 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictA7   ON dictA7 (url_id);

CREATE TABLE dictA8 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictA8   ON dictA8 (url_id);

CREATE TABLE dictA9 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictA9   ON dictA9 (url_id);

CREATE TABLE dictAA (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictAA   ON dictAA (url_id);

CREATE TABLE dictAB (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictAB   ON dictAB (url_id);

CREATE TABLE dictAC (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictAC   ON dictAC (url_id);

CREATE TABLE dictAD (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictAD   ON dictAD (url_id);

CREATE TABLE dictAE (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictAE   ON dictAE (url_id);

CREATE TABLE dictAF (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictAF   ON dictAF (url_id);

CREATE TABLE dictB0 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictB0   ON dictB0 (url_id);

CREATE TABLE dictB1 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictB1   ON dictB1 (url_id);

CREATE TABLE dictB2 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictB2   ON dictB2 (url_id);

CREATE TABLE dictB3 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictB3   ON dictB3 (url_id);

CREATE TABLE dictB4 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictB4   ON dictB4 (url_id);

CREATE TABLE dictB5 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictB5   ON dictB5 (url_id);

CREATE TABLE dictB6 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictB6   ON dictB6 (url_id);

CREATE TABLE dictB7 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictB7   ON dictB7 (url_id);

CREATE TABLE dictB8 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictB8   ON dictB8 (url_id);

CREATE TABLE dictB9 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictB9   ON dictB9 (url_id);

CREATE TABLE dictBA (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictBA   ON dictBA (url_id);

CREATE TABLE dictBB (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictBB   ON dictBB (url_id);

CREATE TABLE dictBC (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictBC   ON dictBC (url_id);

CREATE TABLE dictBD (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictBD   ON dictBD (url_id);

CREATE TABLE dictBE (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictBE   ON dictBE (url_id);

CREATE TABLE dictBF (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictBF   ON dictBF (url_id);

CREATE TABLE dictC0 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictC0   ON dictC0 (url_id);

CREATE TABLE dictC1 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictC1   ON dictC1 (url_id);

CREATE TABLE dictC2 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictC2   ON dictC2 (url_id);

CREATE TABLE dictC3 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictC3   ON dictC3 (url_id);

CREATE TABLE dictC4 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictC4   ON dictC4 (url_id);

CREATE TABLE dictC5 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictC5   ON dictC5 (url_id);

CREATE TABLE dictC6 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictC6   ON dictC6 (url_id);

CREATE TABLE dictC7 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictC7   ON dictC7 (url_id);

CREATE TABLE dictC8 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictC8   ON dictC8 (url_id);

CREATE TABLE dictC9 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictC9   ON dictC9 (url_id);

CREATE TABLE dictCA (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictCA   ON dictCA (url_id);

CREATE TABLE dictCB (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictCB   ON dictCB (url_id);

CREATE TABLE dictCC (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictCC   ON dictCC (url_id);

CREATE TABLE dictCD (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictCD   ON dictCD (url_id);

CREATE TABLE dictCE (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictCE   ON dictCE (url_id);

CREATE TABLE dictCF (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictCF   ON dictCF (url_id);

CREATE TABLE dictD0 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictD0   ON dictD0 (url_id);

CREATE TABLE dictD1 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictD1   ON dictD1 (url_id);

CREATE TABLE dictD2 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictD2   ON dictD2 (url_id);

CREATE TABLE dictD3 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictD3   ON dictD3 (url_id);

CREATE TABLE dictD4 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictD4   ON dictD4 (url_id);

CREATE TABLE dictD5 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictD5   ON dictD5 (url_id);

CREATE TABLE dictD6 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictD6   ON dictD6 (url_id);

CREATE TABLE dictD7 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictD7   ON dictD7 (url_id);

CREATE TABLE dictD8 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictD8   ON dictD8 (url_id);

CREATE TABLE dictD9 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictD9   ON dictD9 (url_id);

CREATE TABLE dictDA (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictDA   ON dictDA (url_id);

CREATE TABLE dictDB (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictDB   ON dictDB (url_id);

CREATE TABLE dictDC (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictDC   ON dictDC (url_id);

CREATE TABLE dictDD (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictDD   ON dictDD (url_id);

CREATE TABLE dictDE (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictDE   ON dictDE (url_id);

CREATE TABLE dictDF (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictDF   ON dictDF (url_id);

CREATE TABLE dictE0 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictE0   ON dictE0 (url_id);

CREATE TABLE dictE1 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictE1   ON dictE1 (url_id);

CREATE TABLE dictE2 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictE2   ON dictE2 (url_id);

CREATE TABLE dictE3 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictE3   ON dictE3 (url_id);

CREATE TABLE dictE4 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictE4   ON dictE4 (url_id);

CREATE TABLE dictE5 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictE5   ON dictE5 (url_id);

CREATE TABLE dictE6 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictE6   ON dictE6 (url_id);

CREATE TABLE dictE7 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictE7   ON dictE7 (url_id);

CREATE TABLE dictE8 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictE8   ON dictE8 (url_id);

CREATE TABLE dictE9 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictE9   ON dictE9 (url_id);

CREATE TABLE dictEA (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictEA   ON dictEA (url_id);

CREATE TABLE dictEB (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictEB   ON dictEB (url_id);

CREATE TABLE dictEC (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictEC   ON dictEC (url_id);

CREATE TABLE dictED (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictED   ON dictED (url_id);

CREATE TABLE dictEE (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictEE   ON dictEE (url_id);

CREATE TABLE dictEF (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictEF   ON dictEF (url_id);

CREATE TABLE dictF0 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictF0   ON dictF0 (url_id);

CREATE TABLE dictF1 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictF1   ON dictF1 (url_id);

CREATE TABLE dictF2 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictF2   ON dictF2 (url_id);

CREATE TABLE dictF3 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictF3   ON dictF3 (url_id);

CREATE TABLE dictF4 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictF4   ON dictF4 (url_id);

CREATE TABLE dictF5 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictF5   ON dictF5 (url_id);

CREATE TABLE dictF6 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictF6   ON dictF6 (url_id);

CREATE TABLE dictF7 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictF7   ON dictF7 (url_id);

CREATE TABLE dictF8 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictF8   ON dictF8 (url_id);

CREATE TABLE dictF9 (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictF9   ON dictF9 (url_id);

CREATE TABLE dictFA (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictFA   ON dictFA (url_id);

CREATE TABLE dictFB (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictFB   ON dictFB (url_id);

CREATE TABLE dictFC (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictFC   ON dictFC (url_id);

CREATE TABLE dictFD (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictFD   ON dictFD (url_id);

CREATE TABLE dictFE (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictFE   ON dictFE (url_id);

CREATE TABLE dictFF (
  url_id int             NOT NULL,
  secno  smallint        NOT NULL,
  word   varchar(255)    NOT NULL,
  intag  varbinary(4000) NOT NULL,
  PRIMARY KEY(word,url_id,secno)
);
CREATE  INDEX wdictFF   ON dictFF (url_id);
